@@ -27,7 +27,7 @@ flush(stderr()); flush(stdout())
 ###   ogcEIDName ogcFIDName ogcGeometryOperandName ogcGeometryOperandsName
 ###   ogcIdCapabilities ogcGeometryOperandEnvelopeName
 ###   ogcGeometryOperandPolygonName ogcGeometryOperandPointName
-###   ogcGeometryOperandLineStringName ogcIntersectsName
+###   ogcGeometryOperandLineStringName ogcIntersectsName ogcLiteralName
 ###   ogcLogicalOperatorsName ogcNamespacePrefix ogcOverlapsName
 ###   ogcPropertyNameName ogcScalarCapabilitiesName
 ###   ogcSpatialCapabilitiesName ogcSpatialOperatorName
@@ -75,12 +75,14 @@ flush(stderr()); flush(stdout())
 ###   sweDataRecordName sweFieldName sweTimeName sweQuantityName
 ###   sweCategoryName sweBooleanName sweCountName sweEncodingName
 ###   sweTextBlockName sweValuesName sweValueName sweCodeSpaceName
-###   sweTextName sweUomName xmlInternalDocumentName xmlTextNodeName
+###   sweTextName sweUomName sweCoordinateName sweLocationName
+###   swePositionName sweVectorName xmlInternalDocumentName xmlTextNodeName
 ###   OwsExceptionsData ogcComparisonOperatorsName ogcTempOpTMOverlappedBy
 ###   owsNamespacePrefix sosDescribeFeatureTypeName
 ###   sosDescribeObservationTypeName sosDescribeResultModelName
 ###   sosGetFeatureOfInterestTimeName sosGetResultName
 ###   sosInsertObservationName sosRegisterSensorName mimeTypeCSV mimeTypeOM
+###   mimeTypeSML mimeTypeXML
 ### Keywords: constants XML
 
 ### ** Examples
@@ -260,6 +262,7 @@ flush(stderr()); flush(stdout())
 ###   sosFeaturesOfInterest,GmlFeatureCollection-method
 ###   sosTime,GmlTimeInstant-method sosTime,GmlTimeInstantProperty-method
 ###   sosTime,GmlTimePeriod-method sosTime,GmlTimePosition-method
+###   summary.GmlTimePeriod print.summary.GmlTimePeriod
 ### Keywords: classes utilities
 
 ### ** Examples
@@ -433,10 +436,10 @@ flush(stderr()); flush(stdout())
 ###   print,OwsOperationsMetadata-method print,OwsRange-method
 ###   print,OwsServiceIdentification-method
 ###   print,OwsServiceOperation-method print,OwsServiceProvider-method
-###   show,OwsCapabilities_1.1.0-method show,OwsCapabilities_2.0.0-method
-###   show,OwsCapabilities-method show,OwsContents-method
-###   show,OwsException-method show,OwsExceptionReport-method
-###   show,OwsGetCapabilities_1.1.0-method
+###   print.summary.OwsRange show,OwsCapabilities_1.1.0-method
+###   show,OwsCapabilities_2.0.0-method show,OwsCapabilities-method
+###   show,OwsContents-method show,OwsException-method
+###   show,OwsExceptionReport-method show,OwsGetCapabilities_1.1.0-method
 ###   show,OwsGetCapabilities_2.0.0-method show,OwsGetCapabilities-method
 ###   show,OwsOperation-method show,OwsOperationsMetadata-method
 ###   show,OwsRange-method show,OwsServiceIdentification-method
@@ -454,6 +457,8 @@ flush(stderr()); flush(stdout())
 ###   OwsException OwsGetCapabilities OwsOperation OwsOperationsMetadata
 ###   OwsRange OwsServiceIdentification OwsServiceProvider
 ###   sosResult,OwsExceptionReport-method
+###   sosTitle,OwsServiceIdentification-method
+###   sosAbstract,OwsServiceIdentification-method summary.OwsRange
 ### Keywords: classes utilities
 
 ### ** Examples
@@ -494,7 +499,9 @@ flush(stderr()); flush(stdout())
 ###   print,OmMeasurement-method toString,OmMeasurement-method
 ###   sosResult,OmMeasurement-method sosProcedures,OmMeasurement-method
 ###   sosFeatureIds,OmMeasurement-method
-###   sosFeaturesOfInterest,OmMeasurement-method names.OmMeasurement
+###   sosFeaturesOfInterest,OmMeasurement-method
+###   sosGetCRS,OmMeasurement-method names.OmMeasurement
+###   as.data.frame.OmMeasurement as.SpatialPointsDataFrame.OmMeasurement
 ### Keywords: classes
 
 ### ** Examples
@@ -528,6 +535,7 @@ flush(stderr()); flush(stdout())
 ###   sosFeatureIds,OmObservation-method
 ###   sosObservedProperties,OmObservation-method
 ###   sosGetCRS,OmObservation-method
+###   as.SpatialPointsDataFrame.OmObservation
 ### Keywords: classes
 
 ### ** Examples
@@ -577,6 +585,8 @@ flush(stderr()); flush(stdout())
 ###   sosObservedProperties,OmObservationCollection-method
 ###   sosFeaturesOfInterest,OmObservationCollection
 ###   sosFeaturesOfInterest,OmObservationCollection-method
+###   as.SpatialPointsDataFrame.OmObservationCollection
+###   sosGetCRS,OmObservationCollection-method
 ### Keywords: classes
 
 ### ** Examples
@@ -622,22 +632,23 @@ flush(stderr()); flush(stdout())
 ### Name: SensorML-class
 ### Title: Classes of the Namespace sml
 ### Aliases: SensorML-class show,SensorML-method print,SensorML-method
-###   toString,SensorML-method SensorML sml
+###   toString,SensorML-method SensorML sml sosId,SensorML-method
+###   sosName,SensorML-method sosAbstract,SensorML-method
+###   sosCoordinates,SensorML-method as.SensorML.SpatialPointsDataFrame
+###   plot.SensorML
 ### Keywords: classes
 
 ### ** Examples
 
 showClass("SensorML")
 
-# create a XmlInternalDocument and a SensorML class with it
-xml <- xmlParse("<SensorML />")
-sml <- SensorML(xml)
-
-# print it
-print(sml)
-
-# access the inner document
-sml@xml
+## Not run: 
+##D weathersos <- SOS("http://v-swe.uni-muenster.de:8080/WeatherSOS/sos")
+##D proc1 <- sosProcedures(weathersos)[[1]][[1]]
+##D proc1.descr <- describeSensor(weathersos, proc1, verbose = TRUE)
+##D plot(proc1.descr)
+##D class(proc1.descr)
+## End(Not run)
 
 
 
@@ -683,29 +694,39 @@ flush(stderr()); flush(stdout())
 ###   sosResponseMode,OwsOperation-method
 ###   sosResponseMode,SosObservationOffering-method sosResultModels
 ###   sosResultModels-methods sosResultModels,SOS-method
-###   sosResultModels,OwsOperation-method sosServiceIdentification
-###   sosServiceIdentification-methods sosServiceIdentification,SOS-method
-###   sosServiceProvider sosServiceProvider-methods
-###   sosServiceProvider,SOS-method sosSrsName sosSrsName-methods
-###   sosSrsName,SOS-method sosTimeFormat sosTimeFormat-methods
-###   sosTimeFormat,SOS-method sosUrl sosUrl-methods sosUrl,SOS-method
-###   sosUrl,SOS_1.0.0-method sosVersion sosVersion-methods
-###   sosVersion,SOS-method sosExceptionCodeMeaning
+###   sosResultModels,OwsOperation-method sosResult,character-method
+###   sosServiceIdentification sosServiceIdentification-methods
+###   sosServiceIdentification,SOS-method sosServiceProvider
+###   sosServiceProvider-methods sosServiceProvider,SOS-method sosSrsName
+###   sosSrsName-methods sosSrsName,SOS-method sosTimeFormat
+###   sosTimeFormat-methods sosTimeFormat,SOS-method sosUrl sosUrl-methods
+###   sosUrl,SOS-method sosUrl,SOS_1.0.0-method sosVersion
+###   sosVersion-methods sosVersion,SOS-method sosExceptionCodeMeaning
 ###   sosExceptionCodeMeaning,character-method sosBoundedBy
 ###   sosBoundedBy-method sosBoundedBy,list-method sosCoordinates
-###   sosCoordinates-method sosCoordinates,list-method sosId sosId-method
+###   sosCoordinates-method sosCoordinates,list-method
+###   sosCoordinates,SosObservationOffering-method sosId sosId-method
 ###   sosId,list-method sosSrsName sosSrsName-method sosFeatureIds
 ###   sosFeatureIds-method sosFeatureIds,list-method
 ###   sosObservedProperties,list-method sosFeaturesOfInterest,list-method
-###   sosGetCRS sosGetCRS-method sosGetCRS,character-method sosName
-###   sosName-method sosName,list-method sosName,OwsServiceProvider-method
-###   sosName,OwsGetCapabilities-method sosName,OwsOperation-method
-###   sosName,SosDescribeSensor-method sosName,SosGetObservation-method
-###   sosName,SosGetObservationById-method sosEncoders
+###   sosGetCRS sosGetCRS-method sosGetCRS,SOS-method sosGetCRS,list-method
+###   sosGetCRS,character-method sosGetCRS,SosObservationOffering-method
+###   sosName sosName-method sosName,list-method
+###   sosName,OwsServiceProvider-method sosName,OwsGetCapabilities-method
+###   sosName,OwsOperation-method sosName,SosDescribeSensor-method
+###   sosName,SosGetObservation-method sosName,SosGetObservationById-method
+###   sosTitle sosTitle-method sosTitle,SOS-method sosAbstract
+###   sosAbstract-method sosAbstract,SOS-method sosEncoders
 ###   sosEncoders,SOS-method sosOperations sosOperations,SOS-method
 ###   sosOperations,OwsCapabilities-method
 ###   sosOperations,SosCapabilities_1.0.0-method sosGetDCP
-###   sosGetDCP,SOS,character-method
+###   sosGetDCP,SOS,character-method sosSwitchCoordinates
+###   sosSwitchCoordinates-method sosSwitchCoordinates,SOS-method plot.SOS
+###   plot,SOS,missing-method plot.SosObservationOffering
+###   plot,SosObservationOffering,missing-method
+###   as.SosObservationOffering.SpatialPolygons print.summary.SOS
+###   print.summary.SosObservationOffering summary.SosObservationOffering
+###   summary.SOS sosChanges
 ### Keywords: classes
 
 ### ** Examples
@@ -725,6 +746,10 @@ showClass("SOS")
 ##D 
 ##D # get the meaning of an exception code
 ##D sosExceptionCodeMeaning(ex@exceptionCode)
+##D 
+##D # print the changes document
+##D sosChanges()
+##D 
 ## End(Not run)
 
 # create a CRS object from a URN CRS string
@@ -733,7 +758,6 @@ sosGetCRS("urn:ogc:def:crs:EPSG:4217")
 
 
 
-
 cleanEx()
 nameEx("SWE")
 ### * SWE
@@ -1096,6 +1120,9 @@ flush(stderr()); flush(stdout())
 ###   sosParse-methods sosParse,SOS_1.0.0,character-method
 ###   sosParse,SOS_1.0.0,character,logical-method parseNoParsing parseCSV
 ###   parseFile parseFile-method parseFile,SOS_1.0.0,character-method
+###   parseCoordinate parseCoordinate-method parseVector parseVector-method
+###   parseLocation parseLocation-method parseSwePosition
+###   parseSwePosition-method
 ### Keywords: methods misc
 
 ### ** Examples
